pub fn apply_profile(
profile: &dyn ControlProfile,
findings: &[ControlFinding],
) -> Vec<ProfileOutcome>Expand description
Applies a profile to all findings and returns the mapped outcomes.
pub fn apply_profile(
profile: &dyn ControlProfile,
findings: &[ControlFinding],
) -> Vec<ProfileOutcome>Applies a profile to all findings and returns the mapped outcomes.