classify_scope

Function classify_scope 

pub fn classify_scope(code_files_count: usize, components: usize) -> Severity
Classify the scope of a change request based on the number of connected components among its changed code files. Verified by Creusot in gh-verify-verif crate.