classify_pr_size

Function classify_pr_size 

pub fn classify_pr_size(
    total_lines: usize,
    total_files: usize,
    warn_lines: usize,
    warn_files: usize,
    error_lines: usize,
    error_files: usize,
) -> Severity
Classify a change request’s size into a severity level.

Returns Error when either dimension exceeds its error threshold, Warning when either exceeds its warning threshold, Pass otherwise.